## $Id: applicant.py 9482 2012-10-31 08:25:49Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from zope.interface import implementedBy
from waeup.kofa.applicants.applicant import Applicant, ApplicantFactory
from waeup.kofa.utils.helpers import attrs_to_fields
from kofacustom.nigeria.applicants.interfaces import(
    INigeriaApplicant,
    INigeriaUGApplicantEdit, INigeriaPGApplicantEdit,
    IPUTMEApplicantEdit)

class NigeriaApplicant(Applicant):

    grok.implements(INigeriaApplicant, INigeriaUGApplicantEdit,
        INigeriaPGApplicantEdit, IPUTMEApplicantEdit)
    grok.provides(INigeriaApplicant)

    # Meanwhile perm_address has been removed but the attribute still exists in
    # some applicant objects. So we'll leave it until all 2012 students
    # have been created.
    create_names = Applicant.create_names + [
        'lga', 'nationality', 'perm_address']  

    def _setStudyCourseAttributes(self, studycourse):
        if self.applicant_id.startswith('pude'):
            studycourse.entry_mode = u'de_ft'
            studycourse.current_level = 200
        else:
            studycourse.entry_mode = self.course_admitted.study_mode
            studycourse.current_level = self.course_admitted.start_level
        studycourse.certificate = self.course_admitted
        studycourse.entry_session = self.__parent__.year
        studycourse.current_session = self.__parent__.year
        return

# Set all attributes of NigeriaApplicant required in INigeriaApplicant as field
# properties. Doing this, we do not have to set initial attributes
# ourselves and as a bonus we get free validation when an attribute is
# set.
NigeriaApplicant = attrs_to_fields(NigeriaApplicant)

class NigeriaApplicantFactory(ApplicantFactory):
    """A factory for customized applicants.
    """

    def __call__(self, *args, **kw):
        return NigeriaApplicant()

    def getInterfaces(self):
        return implementedBy(NigeriaApplicant)
